@@ -255,14 +255,21 @@ func (v *vgrep) ripgrepInstalled() bool {
 	return installed
 }
 
-func (v *vgrep) getGrepType() (grepType string) {
+func (v *vgrep) getGrepType() (string) {
 	out, _ := v.runCommand([]string{"grep", "--version"}, "")
+	if len(out) == 0 {
+		return ""
+	}
 	versionString := out[0]
 	// versionString = "grep (BSD grep) 2.5.1-FreeBSD"
-	versionRegex := regexp.MustCompile(`\(([[:alpha:]]+) grep\)`)
+	// versionString = "grep (BSD grep, GNU compatible) 2.6.0-FreeBSD"
+	versionRegex := regexp.MustCompile(`\(([[:alpha:]]+) grep`)
 	// versionRegex matches to ["(BSD grep)", "BSD"], return "BSD"
-	grepType = versionRegex.FindStringSubmatch(versionString)[1]
-	return
+	submatch := versionRegex.FindStringSubmatch(versionString)
+	if len(submatch) < 2 {
+		return ""
+	}
+	return submatch[1]
 }
 
 // isVscode checks if the terminal is running inside of vscode.
@@ -367,6 +374,9 @@ func (v *vgrep) splitMatch(match string, greptype string) (file, line, content s
 		}
 		err = fmt.Errorf("unexpected input")
 		return
+	default:
+		err = fmt.Errorf("unknown grep type %q", greptype)
+		return
 	}
 	return
 }
